@@ -2,7 +2,6 @@ import asyncio
 from itertools import repeat
 from typing import (
     Dict,
-    Tuple,
     AsyncGenerator
 )
 from typing import Optional, List, Union
@@ -16,7 +15,7 @@ from aiohttp import (
 from aiohttp.typedefs import LooseCookies
 
 from glQiwiApi.core import AbstractParser
-from glQiwiApi.types import ProxyService, Response
+from glQiwiApi.types import Response
 from glQiwiApi.types.basics import Cached
 
 DEFAULT_TIMEOUT = ClientTimeout(total=5 * 60)
@@ -54,7 +53,6 @@ class HttpXParser(AbstractParser):
             set_timeout: bool = True,
             cookies: Optional[LooseCookies] = None,
             json: Optional[dict] = None,
-            skip_exceptions: bool = False,
             data: Optional[Dict[str, Union[
                 str, int, List[
                     Union[str, int]
@@ -106,11 +104,10 @@ class HttpXParser(AbstractParser):
                 ClientProxyConnectionError,
                 ServerDisconnectedError
         ) as ex:
-            if not skip_exceptions:
-                self.raise_exception(
-                    status_code='400_special_bad_proxy',
-                    json_info=ex
-                )
+            self.raise_exception(
+                status_code='400_special_bad_proxy',
+                json_info=ex
+            )
             return Response.bad_response()
         # Get content and return response
         try:
@@ -173,19 +170,3 @@ class HttpXParser(AbstractParser):
             from asyncio import DefaultEventLoopPolicy as EventLoopPolicy
             asyncio.set_event_loop_policy(EventLoopPolicy())
         return self
-
-    @staticmethod
-    def combine_proxies(
-            proxies: Union[List[ProxyService], Tuple[ProxyService]]
-    ) -> Union[
-        List[ProxyService], Tuple[ProxyService]
-    ]:
-        """
-        Method to combine proxies
-
-        :param proxies:
-        :return: shuffled iterable(list or tuple of CredentialService objects)
-        """
-        import random
-        random.shuffle(proxies)
-        return proxies
