@@ -3,6 +3,7 @@ import time
 from glQiwiApi.types import WrapperData
 
 BASE_QIWI_URL = 'https://edge.qiwi.com'
+BASE_P2P_URL = 'https://api.qiwi.com/partner/bill/v1/bills/'
 
 DEFAULT_QIWI_HEADERS = {
     'Content-Type': 'application/json',
@@ -16,9 +17,13 @@ ERROR_CODE_NUMBERS = {
     "401": "Неверный токен или истек срок действия токена API",
     "403": "Нет прав на данный запрос"
            "(недостаточно разрешений у токена API)",
-    "404": "Не найдена транзакция или"
+    "404": "Не найдена транзакция или "
            "отсутствуют платежи с указанными признаками",
     "423": "Слишком много запросов, сервис временно недоступен",
+    "422": "Неправильно указаны домен/подсеть/хост"
+           " веб-хука(в параметре new_url для URL веб-хука), "
+           "неправильно указаны тип хука или тип транзакции, "
+           "попытка создать хук при наличии уже созданного",
     "405": "Ошибка, связанная с типом запроса к апи,"
            "обратитесь к разработчику или откройте issue",
     "500": "Внутренняя ошибка сервиса",
@@ -157,5 +162,6 @@ __all__ = (
     'COMMISSION_DATA',
     'COMMISSION_TRANSFER',
     'ERROR_CODE_NUMBERS',
-    'BASE_QIWI_URL'
+    'BASE_QIWI_URL',
+    'BASE_P2P_URL'
 )
