@@ -8,9 +8,9 @@ from glQiwiApi.utils.basics import custom_load
 
 class Account(BaseModel):
     alias: str
+    title: str
     fs_alias: str = Field(alias="fsAlias")
     bank_alias: str = Field(alias="bankAlias")
-    title: str
     has_balance: bool = Field(alias="hasBalance")
     balance: Optional[Sum] = Field(const=None)
     currency: int
@@ -18,8 +18,15 @@ class Account(BaseModel):
     is_default_account: bool = Field(alias="defaultAccount")
 
     class Config:
+        """ Pydantic config """
         json_loads = custom_load
 
+        def __str__(self) -> str:
+            return f'Config class with loads={self.json_loads}'
+
+        def __repr__(self) -> str:
+            return self.__str__()
+
 
 __all__ = [
     'Account'
